==> deepin-log-viewer_5.9.7+ds1.orig.tar.xz: deepin-log-viewer-5.9.7/translations/deepin-log-viewer_sr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sr">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Прикажи у управнику података</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Обриши записник</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Освежи</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Заиста желите да обришете записник?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Потврди</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Све</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Данас</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 дана</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>седмица</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 месец</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 месеца</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="vanished">Извези</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Извези</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Све</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Хитно</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Узбуна</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Критично</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Грешка</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Упозорење</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Запажање</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Подаци</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Уклањање грешака</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Пријави се</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Покретање</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Искључи</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Веома критично</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Пратити</translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Извожење...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Успешан извоз</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Неуспешан извоз</translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Извези датотеку</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Период:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Ниво:  </translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>Списак програма:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Стање:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Врста догађаја:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Корисник:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>ПИД:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Поступак:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Корисничко име:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Евиденција покретања</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Евиденција искључивања</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Евиденција пријава</translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Упозорење</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Уклањање грешака</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Подаци</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Грешка</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Хитно</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Узбуна</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Критично</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Запажање</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Пратити</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Веома критично</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Датотека записника је празна</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Прегледач Записника</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Прегледач Записника је користан алат за приказ записника система.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Нема резулталта претраге</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Претражи</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Ниво</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Процес</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Датум и време</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Подаци</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Корисник</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>ПИД</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Извор</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Поступак</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Стање</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Врста догађаја</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Корисничко име</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Ниво:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Процес:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Датум и време:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Подаци:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Нула</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Корисник:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>ПИД:</translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Датум и време</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Зап. система</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Зап. језгра</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Зап. покретања</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>dpkg записник</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Kwin записник</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Xorg записник</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Зап. програма</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Покре.-Искључ. догађај</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>dnf записник</translation>
    </message>
</context>
</TS>

==> deepin-log-viewer_6.5.8+ds1.orig.tar.xz: deepin-log-viewer-6.5.8/translations/deepin-log-viewer_sr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sr">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>Прикажи у управнику података</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>Обриши записник</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Освежи</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>Заиста желите да обришете записник?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Потврди</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>Све</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Данас</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3 дана</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>седмица</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1 месец</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3 месеца</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Извези</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>Све</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Хитно</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Узбуна</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Критично</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Грешка</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Упозорење</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Запажање</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Подаци</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Уклањање грешака</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Пријави се</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>Покретање</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Искључи</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Веома критично</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Пратити</translation>
    </message>
    <message>
        <source>Identity authentication</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Discretionary Access Control</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mandatory access control</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remote</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Document audit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>zip(*.zip)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>Извожење...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Откажи</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>Успешан извоз</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation>Неуспешан извоз</translation>
    </message>
    <message>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>Извези датотеку</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>Период:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>Ниво:  </translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Стање:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>Врста догађаја:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Корисник:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>ПИД:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>Поступак:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Корисничко име:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>Евиденција покретања</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>Евиденција искључивања</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>Евиденција пријава</translation>
    </message>
    <message>
        <source>Audit Type:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Application:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Submodule:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>Упозорење</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>Уклањање грешака</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Подаци</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Грешка</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>Хитно</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>Узбуна</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Критично</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>Запажање</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation>Пратити</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation>Веома критично</translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>Датотека записника је празна</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>Прегледач Записника</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>Прегледач Записника је користан алат за приказ записника система.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>Нема резулталта претраге</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Претражи</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>Ниво</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>Процес</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>Датум и време</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Подаци</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Корисник</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>ПИД</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Извор</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Поступак</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Стање</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>Врста догађаја</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Корисничко име</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>Ниво:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>Процес:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>Датум и време:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>Подаци:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Нула</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Корисник:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>ПИД:</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Time Modified</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SIG</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EXE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Core File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User Name </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Offset</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>Датум и време</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>Зап. система</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>Зап. језгра</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>Зап. покретања</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>dpkg записник</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Kwin записник</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Xorg записник</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>Зап. програма</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>Покре.-Искључ. догађај</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation>dnf записник</translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Custom Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Audit Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Coredump Log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Export logs to the specified path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PATH</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs of specified types</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TYPE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs of specified self-developed applications</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SELF APPNAME</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs within a specified time period</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PERIOD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs within a specified debug level</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>LEVEL</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>BOOT STATUS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EVENT TYPE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs based on keywords search results</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>KEY WORD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Report coredump informations.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs based on app submodel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SUBMODULE</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>10 sec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1 min</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>5 min</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No refresh</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export All</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
